/******************** Module Header *********************
* Module Name: MIDIRES.H
*
* Description: Routines to play back MIDI files/resources
*
* History    : 07-Jan-98 Davide Ficano (DaFi) Created
*              30-Jan-98 DaFi Added Win16 support
*
* *Note      : Use "MIDI" for resources type name
********************************************************/
#ifndef _PLAYMIDIRES_

#define _PLAYMIDIRES_

#ifdef __cplusplus
extern "C" {
#endif

#if !defined(WIN32) && (defined(__WIN32__) || defined(_WIN32))
    #define WIN32
#endif
    
#ifdef WIN32
    #include <tchar.h>

    #ifdef EXPORT_DLL_DIRECTION
        #define DLL_DIRECTION __declspec(dllexport) WINAPI
    #else
        #define DLL_DIRECTION __declspec(dllimport) WINAPI
    #endif /* EXPORT_DLL_DIRECTION */
#else /* Win16 */
    #define _T(x) x
    typedef char TCHAR;
    typedef const char* LPCTSTR;

    #define UNREFERENCED_PARAMETER(x) (x) = (x)
    #define MAX_PATH 260
    #define SND_FILENAME    0x00020000L
    #define SND_RESOURCE    0x00040004L

    #ifdef EXPORT_DLL_DIRECTION
        #define DLL_DIRECTION _export FAR PASCAL
    #else
        #define DLL_DIRECTION FAR PASCAL
    #endif /* EXPORT_DLL_DIRECTION */
#endif

#include <windows.h>
#include <windowsx.h>
#include <mmsystem.h>

/* These macros come from
** "The Black Art of Windows Game Programming" by Eric Lyons */

/* Message handler for MM_MCINOTIFY */
/* void OnMCINotify(HWND hwnd, UINT deviceID, UINT message); */
#define HANDLE_MM_MCINOTIFY(hwnd, wParam, lParam, fn) \
    ((fn)((hwnd), (UINT)LOWORD(lParam), (UINT)(wParam)), 0L)
#define FORWARD_MM_MCINOTIFY(hwnd, deviceID, message, fn) \
            (void)(fn)((hwnd), MM_MCINOTIFY, message, \
            MAKELPARAM((UINT)(deviceID), 0))

/*****
** Use this to play/stop MIDI resources
*****/
BOOL DLL_DIRECTION PlayMidiSound(LPCTSTR pszMidi,
                                 HINSTANCE hMidiInst,
                                 DWORD fdwSound);

/*****
** Support functions for internally use
*****/
#ifdef EXPORT_DLL_DIRECTION

BOOL InitInstance(HINSTANCE hInst);
BOOL CreateHoodWnd(void);
LRESULT CALLBACK HoodWndProc(HWND hwnd, UINT msg,
                             WPARAM wParam, LPARAM lParam);
void OnNcDestroy(HWND hWnd);
void OnMCINotify(HWND hWnd, UINT deviceID, UINT message);
BOOL TransferResource(HINSTANCE hInst, LPCTSTR pszResName);
BOOL WriteMidi(LPBYTE pBuf, DWORD dwSize);
BOOL PlayResource(HINSTANCE hMidiInst,
                  LPCTSTR pszResource, BOOL bAsync);
DWORD PlayFile(LPCTSTR lpszMIDIFileName, BOOL bAsync);
void RemoveFile(void);
void StopPlay(void);

#endif /* EXPORT_DLL_DIRECTION */

#ifdef __cplusplus
}
#endif

#endif /* _PLAYMIDIRES_ */
