// This is a 16 bit sample to use PlayMidiSound
// to play back MIDI placed as resources
#define STRICT

#include <windows.h>
#include "midires.h"
#include "resource.h"
#include <windowsx.h>

HINSTANCE hInst;
HWND      hWndMain, hWndMessage;
char      szAppName[] = "Miditest";

// function prototypes

int      PASCAL        WinMain(HINSTANCE,HINSTANCE,LPSTR,int);
void                   InitApp(HINSTANCE,HINSTANCE,LPSTR,int);
void                   InitAppFirst(HINSTANCE);
void                   InitAppEvery(HINSTANCE,int);
LRESULT CALLBACK       MidiWndProc(HWND,UINT,WPARAM,LPARAM);

int PASCAL WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance,
                   LPSTR lpszCmdLine, int cmdShow)
{
    MSG   msg;

    InitApp(hInstance, hPrevInstance, lpszCmdLine, cmdShow);

    // Get and dispatch messages for this applicaton.
    while (GetMessage(&msg, NULL, 0, 0))
    {
        TranslateMessage(&msg);
        DispatchMessage(&msg);
    }

    return(msg.wParam);
}

void InitApp(HINSTANCE hInstance, HINSTANCE /*hPrevInstance*/,
               LPSTR /*lpszCmdLine*/, int cmdShow)
{
    InitAppFirst(hInstance);

    InitAppEvery(hInstance, cmdShow);
}

void InitAppFirst(HINSTANCE hInstance)
{
    WNDCLASS wc;

    // Define the window class for this application.
    wc.lpszClassName = szAppName;
    wc.hInstance     = hInstance;
    wc.lpfnWndProc   = MidiWndProc;
    wc.hCursor       = LoadCursor(NULL, IDC_ARROW);
    wc.hIcon         = LoadIcon(hInstance, szAppName);
    wc.lpszMenuName  = NULL;
    wc.hbrBackground = (HBRUSH)GetStockObject(WHITE_BRUSH);
    wc.style         = CS_HREDRAW | CS_VREDRAW;
    wc.cbClsExtra    = 0;
    wc.cbWndExtra    = 0;

    // Register the class
    RegisterClass(&wc);
}

void InitAppEvery(HINSTANCE hInstance, int cmdShow)
{
    hInst = hInstance;

    hWndMain = CreateWindow(szAppName, szAppName,
                            WS_OVERLAPPEDWINDOW,
                            100, 100, 200, 200,
                            NULL, NULL, hInstance, NULL);

    ShowWindow(hWndMain, cmdShow);
    UpdateWindow(hWndMain);
}


LRESULT CALLBACK MidiWndProc(HWND hWnd, UINT message,
                                WPARAM wParam, LPARAM lParam)
{
    switch (message)
    {
        case WM_CREATE:
            CreateWindow("button", "&Stop",
                         WS_CHILD | WS_VISIBLE | BS_PUSHBUTTON,
                         20, 40, 120, 30,
                         hWnd, (HMENU)IDC_STOP, hInst, NULL);

            CreateWindow("button", "&Play",
                         WS_CHILD | WS_VISIBLE | BS_PUSHBUTTON,
                         20, 80, 120, 30,
                         hWnd, (HMENU)IDC_PLAYRES, hInst, NULL);
            hWndMessage = CreateWindow("static", NULL,
                                       WS_CHILD | 
                                       WS_VISIBLE | WS_BORDER,
                                       20, 120, 140, 30,
                                       hWnd, (HMENU)IDC_MESSAGE,
                                       hInst, NULL);

            return(DefWindowProc(hWnd, message, wParam, lParam));

        case WM_COMMAND:
            switch (GET_WM_COMMAND_ID(wParam, lParam))
            {
                case IDC_STOP:
                    PlayMidiSound(NULL, NULL, 0);
                    SetWindowText(hWndMessage, "Playing stopped");
                    break;
                case IDC_PLAYRES:
                    if (PlayMidiSound(MAKEINTRESOURCE(IDR_MIDI1), 
                                      hInst,
                                      SND_RESOURCE | SND_ASYNC))
                        SetWindowText(hWndMessage, 
                                      "Start Playing");
                    else
                        SetWindowText(hWndMessage, 
                                      "Unable to play");
                    break;
                default:
                    break;
            }
          break;

        case WM_NCDESTROY:
            // If playing stop and remove file
            PlayMidiSound(NULL, NULL, 0);
            break;
        case WM_DESTROY:
            PostQuitMessage(0);
            break;

        case WM_CLOSE:
            DestroyWindow(hWnd);
            break;

        default:
          return(DefWindowProc(hWnd, message, wParam, lParam));
    }
    return(0L);
}
